pub fn init_mode(default: impl Into<String>)
Selects default only when no mode is active yet. Called at app start and after a hot reload so a selection restored by the rsx hot-reload bridge is not clobbered by the default.
default