pub fn toggle_dark()Expand description
Flips between the designated light and dark modes. Reads the current scheme non-reactively so it is safe to call from an event handler.
pub fn toggle_dark()Flips between the designated light and dark modes. Reads the current scheme non-reactively so it is safe to call from an event handler.